@@ -11,7 +11,7 @@ def get_main_parser(parser=None):
         parser = set_base_parser()
 
     sp = parser.add_subparsers(
-        dest='cli2',
+        dest='auth_cli',
         required=True,
     )
 
